/*
 * Sixth 3D engine demos. Author: Svjatoslav Agejenko. 
 * This project is released under Creative Commons Zero (CC0) license.
 *
*/

package eu.svjatoslav.sixth.e3d.examples.launcher;

import eu.svjatoslav.sixth.e3d.examples.*;

import javax.swing.*;
import java.awt.event.ActionEvent;
import java.io.IOException;

class MenuPanel extends JPanel {
    private static final long serialVersionUID = 2012721856427052560L;

    MenuPanel() {
        final GroupLayout groupLayout = new GroupLayout(this);
        GroupLayout.SequentialGroup sequentialGroup = groupLayout.createSequentialGroup();
        sequentialGroup.addComponent(new JLabel("Choose an example to launch:"));
        sequentialGroup.addComponent(new JButton(new ShowOctree()));
        sequentialGroup.addComponent(new JButton(new ShowMathGraphs()));
        sequentialGroup.addComponent(new JButton(new ShowPointCloud()));
        sequentialGroup.addComponent(new JButton(new ShowRain()));
        sequentialGroup.addComponent(new JButton(new ShowTextEditors()));
        sequentialGroup.addComponent(new JButton(new ShowGameOfLife()));
        sequentialGroup.addComponent(new JButton(new ShowRandomPolygons()));
    }

    private class ShowTextEditors extends AbstractAction {
        ShowTextEditors() {
            putValue(NAME, "Text editors");
        }

        @Override
        public void actionPerformed(final ActionEvent e) {
            TextEditorDemo.main(null);
        }
    }


    private class ShowRain extends AbstractAction {
        ShowRain() {
            putValue(NAME, "Raining numbers");
        }

        @Override
        public void actionPerformed(final ActionEvent e) {
            RainingNumbersDemo.main(null);
        }
    }

    private class ShowPointCloud extends AbstractAction {
        ShowPointCloud() {
            putValue(NAME, "Pointcloud galaxy");
        }

        @Override
        public void actionPerformed(final ActionEvent e) {
            PointCloudDemo.main(null);
        }
    }

    private class ShowMathGraphs extends AbstractAction {
        ShowMathGraphs() {
            putValue(NAME, "Mathematical graphs");
        }

        @Override
        public void actionPerformed(final ActionEvent e) {
            try {
                GraphDemo.main(null);
            } catch (final IOException e1) {
                e1.printStackTrace();
            }
        }
    }

    private class ShowRandomPolygons extends AbstractAction {
        ShowRandomPolygons() {
            putValue(NAME, "Random polygons");
        }

        @Override
        public void actionPerformed(final ActionEvent e) {
            RandomPolygonsDemo.main(null);
        }
    }

    private class ShowOctree extends AbstractAction {
        ShowOctree() {
            putValue(NAME, "Volumetric Octree");
        }

        @Override
        public void actionPerformed(final ActionEvent e) {
            OctreeDemo.main(null);
        }
    }

    private class ShowGameOfLife extends AbstractAction {
        ShowGameOfLife() {
            putValue(NAME, "Game of Life");
        }

        @Override
        public void actionPerformed(final ActionEvent e) {
            eu.svjatoslav.sixth.e3d.examples.life.Main.main(null);
        }
    }

}
